"""Data models for solution orchestration.

DEPRECATED: The old Planner/Executor/Assembler models have been removed.
SolutionResult now lives in vbagent.agents.orchestration.solution_orchestrator.
"""
